Documentation
¶
Index ¶
Constants ¶
const ( FieldHelmStatusOutput = "status" FieldHelmOptionsInput = "helmOptions" )
Variables ¶
This section is empty.
Functions ¶
func Construct ¶
func Construct(ctx *pulumi.Context, c Chart, typ, name string, args ChartArgs, inputs provider.ConstructInputs, opts pulumi.ResourceOption) (*provider.ConstructResult, error)
Construct is the RPC call that initiates the creation of a new Chart component. It creates, registers, and returns the resulting component object. This contains most of the boilerplate so that the calling component can be relatively simple.
func InitDefaults ¶ added in v0.0.11
func InitDefaults(args *helmv3.ReleaseType, chart, repo string, values interface{})
InitDefaults copies the default chart, repo, and values onto the args struct.
func To ¶ added in v0.0.11
func To(args *helmv3.ReleaseType) *helmv3.ReleaseArgs
To turns the args struct into a Helm-ready ReleaseArgs struct.
Types ¶
type Chart ¶
type Chart interface {
pulumi.ComponentResource
// Type returns the fully qualified Pulumi type token for this resource.
Type() string
// SetOutputs registers the resulting Helm Release child resource, after it
// has been created and registered. This contains the Status, among other things.
SetOutputs(out helmv3.ReleaseStatusOutput)
// DefaultChartName returns the default name for this chart.
DefaultChartName() string
// DefaultRepo returns the default Helm repo URL for this chart.
DefaultRepoURL() string
}
Chart represents a strongly typed Helm Chart resource. For the most part, it merely participates in the Pulumi resource lifecycle (by virtue of extending pulumi.ComponentResource), but it also offers a few specific helper methods.
type ChartArgs ¶
type ChartArgs interface {
R() **helmv3.ReleaseType
}
ChartArgs is a properly annotated structure (with `pulumi:""` and `json:""` tags) which carries the strongly typed argument payload for the given Chart resource.